pub unsafe extern "C" fn zts_core_query_path_count(
peer_id: u64,
) -> c_intExpand description
@brief Lock the core service so that queries about addresses, routes, paths, etc. can be performed.
Notice: Core locking functions are intended to be used by high-level language wrappers. Only lock the core if you know exactly what you are doing. zts_core_lock_obtain() and zts_core_lock_release() must be called before and after this function.
@return ZTS_ERR_OK if successful. ZTS_ERR_SERVICE if the core service is unavailable.