pub unsafe extern "C" fn zts_init_allow_roots_cache(
allowed: c_uint,
) -> c_intExpand description
@brief Enable or disable whether the node will cache root definitions (enabled
by default when zts_init_from_storage() is used.) Must be called before zts_node_start().
@param enabled Whether or not this feature is enabled
@return ZTS_ERR_OK if successful, ZTS_ERR_SERVICE if the node
experiences a problem, ZTS_ERR_ARG if invalid argument.